@@ -25,6 +25,7 @@
 
 #include <FL/Fl_Preferences.H>
 #include <FL/Fl_Progress.H>
+#include <FL/Enumerations.H>
 
 #include "status.h"
 #include "util.h"
@@ -131,6 +132,7 @@ status progStatus = {
 
 	0,			// int  schema;
 	true,		// bool hrd_buttons
+	FL_WHEN_CHANGED,	// int sliders_button
 
 	0,			// int  line_out;
 	false,		// bool data_port;
@@ -699,6 +701,7 @@ void status::saveLastState()
 	spref.set("rpc_level", rpc_level);
 
 	spref.set("hrd_buttons", hrd_buttons);
+	spref.set("sliders_button", sliders_button);
 }
 
 bool status::loadXcvrState(string xcvr)
@@ -762,11 +765,13 @@ bool status::loadXcvrState(string xcvr)
 
 		spref.get("aux_serial_port", defbuffer, "NONE", 499);
 		aux_serial_port = defbuffer;
+
 		if (spref.get("aux_rts", i, i)) aux_rts = i;
 		if (spref.get("aux_dtr", i, i)) aux_dtr = i;
 
 		spref.get("sep_serial_port", defbuffer, "NONE", 499);
 		sep_serial_port = defbuffer;
+
 		if (spref.get("sep_rtsptt", i, i)) sep_rtsptt = i;
 		if (spref.get("sep_dtrptt", i, i)) sep_dtrptt = i;
 		if (spref.get("sep_rtsplus", i, i)) sep_rtsplus = i;
@@ -1079,6 +1084,7 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("rpc_level", rpc_level, rpc_level);
 
 		if (spref.get("hrd_buttons", i, i)) hrd_buttons = i;
+		spref.get("sliders_button", sliders_button, sliders_button);
 
 		return true;
 	}
